@@ -9,7 +9,7 @@ require Exporter;
 require DynaLoader;
 
 our @ISA = qw(Exporter DynaLoader);
-# Items to export into callers namespace by default. Note: do not export
+# Items to export into caller's namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
@@ -65,7 +65,7 @@ sub fetch() {
     $invalid_args = 1;
   }
   if( $invalid_args ) {
-    Carp::carp( "USAGE: \$mset->fetch(\$key, \$value)" ); # FIXME - wrong!
+    Carp::carp( "USAGE: \$mset->fetch(\$begin, \$end), \$mset->fetch(\$msetiterator), \$mset->fetch()" );
     exit;
   }
 }
@@ -75,11 +75,11 @@ sub convert_to_percent() {
   my $invalid_args;
   if( scalar(@_) == 1 ) {
     my $arg = shift;
-    my $arg_class = shift;
+    my $arg_class = ref $arg;
     if( !$arg_class ) {
-      $self->convert_to_percent1($arg);
+      return $self->convert_to_percent1($arg);
     } elsif( $arg_class eq 'Search::Xapian::MSetIterator' ) {
-      $self->convert_to_percent2($arg);
+      return $self->convert_to_percent2($arg);
     } else {
       $invalid_args = 1;
     }
