@@ -9,7 +9,7 @@ require Exporter;
 require DynaLoader;
 
 our @ISA = qw(Exporter DynaLoader);
-# Items to export into callers namespace by default. Note: do not export
+# Items to export into caller's namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
@@ -23,7 +23,12 @@ our @EXPORT = qw( );
 # Preloaded methods go here.
 
 use overload '++' => sub { $_[0]->inc() },
+	     '--' => sub { $_[0]->dec() },
              '='  => sub { $_[0]->clone() },
+	     'eq' => sub { $_[0]->equal($_[1]) },
+	     'ne' => sub { $_[0]->nequal($_[1]) },
+	     '==' => sub { $_[0]->equal($_[1]) },
+	     '!=' => sub { $_[0]->nequal($_[1]) },
              'fallback' => 1;
 
 sub clone() {
